# Copyright (C) 2010 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

"""GNOME Terminal Test
Test the Gnome terminal:
  - Add a new profile.
  - Delete a profile.
  - Zoom out
  - Zoom in
  - Open tabs
  - Close tabs

To run it with:
$ mago-ng <path_to_this_file>

"""

from mago import TestCase
import unittest
import ldtp
import ooldtp

TERMINAL = 'frm*@*'
MNU_PROFILE = 'mnuProfile*'
DLG_PROFILE = 'dlgProfiles'
BTN_CLOSE = 'btnClose'
BTN_NEWPROFILE = 'btnNew'
DLG_NEWPROFILE = 'dlgNewProfile'
TXT_PROFILENAME = 'txtProfilename'
PROFILE_NAME = 'Prueba' 
BTN_CREATE = 'btnCreate'
DLG_EDITINGPROFILE = 'dlgEditingProfile*'
PROFILE_LIST = 'tblProfilelist'
BTN_DELETE = 'btnDelete'
DLG_QUESTION = 'dlgQuestion'
ZOOM_OUT = 'mnuZoomOut'
ZOOM_IN = 'mnuZoomIn'
FULLSCREEN = 'mnuFullScreen'
OPENTAB = 'mnuOpenTab'
CLOSETAB = 'mnuCloseTab'

class TerminalTests(TestCase):    
    launcher = 'gnome-terminal'
    window_name =  TERMINAL
    setupOnce = True
    
    def test_01_add_new_profile(self):
        t = ooldtp.context(self.application.get_windowname(discover = True))
        t.getchild(MNU_PROFILE).selectmenuitem()
        ldtp.wait(2)
        self.assertTrue(ldtp.guiexist(DLG_PROFILE))
        p = ooldtp.context(DLG_PROFILE)
        p.getchild(BTN_NEWPROFILE).click()
        
        ldtp.waittillguiexist(DLG_NEWPROFILE)
        np = ooldtp.context(DLG_NEWPROFILE)
        np.getchild(TXT_PROFILENAME).settextvalue(PROFILE_NAME)
        np.getchild(BTN_CREATE).click()
        ldtp.waittillguiexist(DLG_EDITINGPROFILE)
        ep = ooldtp.context(DLG_EDITINGPROFILE)
        ep.getchild(BTN_CLOSE).click()
        p.getchild(BTN_CLOSE).click()
        

    def test_02_delete_profile(self):
        t = ooldtp.context(self.application.get_windowname(discover = True))
        t.getchild(MNU_PROFILE).selectmenuitem()
        ldtp.wait(2)
        
        self.assertTrue(ldtp.guiexist(DLG_PROFILE))
        
        p = ooldtp.context(DLG_PROFILE)
        pl = p.getchild(PROFILE_LIST)
        self.assertTrue(pl.selectrowpartialmatch(PROFILE_NAME))
        p.getchild(BTN_DELETE).click()
        
        ldtp.waittillguiexist(DLG_QUESTION)
        
        q = ooldtp.context(DLG_QUESTION)
        q.getchild(BTN_DELETE).click()
        
        p.getchild(BTN_CLOSE).click()

    def test_03_zoom_out(self):
        t = ooldtp.context(self.application.get_windowname(discover = True))
        zoom = t.getchild(ZOOM_OUT)
        
        while zoom.stateenabled():
            zoom.selectmenuitem()
        self.assertTrue(ldtp.guiexist(t))

    def test_04_zoom_in(self):
        t = ooldtp.context(self.application.get_windowname(discover = True))
        zoom = t.getchild(ZOOM_IN)

        while zoom.stateenabled():
            zoom.selectmenuitem()
   
        self.assertTrue(ldtp.guiexist(t))
    
    def test_05_open_new_tabs(self):
        t = ooldtp.context(self.application.get_windowname(discover = True))
        tabs = t.getchild(OPENTAB)
        t = 0
        while t < 50:
            tabs.selectmenuitem()
            t+=1
        self.assertTrue(ldtp.guiexist(t))
    
    def test_06_close_tabs(self):
        t = ooldtp.context(self.application.get_windowname(discover = True))
        tabs = t.getchild(CLOSETAB)
        while tabs.stateenabled():
            tabs.selectmenuitem()
        self.assertTrue(ldtp.guiexist(t))

if __name__ == "__main__":
    unittest.main()
