# Copyright (C) 2011 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

"""Jockey GTK Test

This is a basic test to verify that jockey-gtk is working correctly.

It checks the following:
    - that clicking the Help button brings up yelp
    - that the activate button is clickable when proprietary drivers are
      available

To run it with:
$ mago-ng <path_to_this_file>
"""

from mago import TestCase
import ldtp
import unittest

class JockeyTests(TestCase):
    """Launcher for the application jockey-gtk
    """
    launcher = 'jockey-gtk'
    window_name = 'dlgAdditionalDrivers'

    def test_help_button(self):
        """Test help button

        This tests that Help regarding proprietary drivers can be accessed.
        """
        ldtp.mouseleftclick(self.window_name, 'Help')
        #help_name = 'frmProprietaryDrivers'
        help_name = 'frmWorkingwithHardwareDevices'
        self.assertTrue(ldtp.waittillguiexist(help_name))
        ldtp.closewindow(help_name)

    def test_activate_is_active(self):
        """Test activate button is available

        This test ensures the activate button is present if there are
        drivers that have not been activated.
        """
        if ldtp.gettextvalue(self.window_name,
                              'lblThisdriverisnotactivated'):
            self.assertTrue(ldtp.objectexist(self.window_name,
                                              'btnActivate'))


if __name__ == "__main__":
    unittest.main()
