# Copyright (C) 2010 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

"""Language Selector Test

Test the gnome-language-selector application

To run it with:
$ mago <path_to_this_file>

"""

from mago import TestCase
import unittest
import ldtp, ooldtp

class TestLanguageSelector(TestCase):
    """Language Selector Test
    """
    launcher = 'gnome-language-selector'
    window_name = 'frmLanguage&Text'

    btnInstallRemove = 'btnInstall/RemoveLanguages'

    frmInstalledLanguages = 'frmInstalledLanguages'
    btnApplyChanges = 'btnApplyChanges'
    chkTranslations = 'chkTranslations'
    chkExtrafonts = 'chkExtrafonts'
    chkInputmethods = 'chkInputmethods'
    chkSpellchecking= 'chkSpellcheckingandwritingaids'
    tblLanguages = 'tbl0'

    def test_01InstallLanguage(self):
        """Test the installation of a language package

           TESTCASE
            caseid: langsel001 - Unique ID for the testcase
            name: administration-language-support-install
            requires:
            command: gnome-language-selector
            _description:
             PURPOSE:
                 1. Verify the ability to install a new language
             STEPS:
                 1. System -> Administration -> Language Support
                 2. Click Install/Remove Language
                 3. Select a new language
                 4. Apply translations
                 5. Select language drop down for Menus
                 6. Set to another language
                 7. Proceed with installation
             VERIFICATION:
                 1. Verifiy that the language is installed

        """
        password = self.testConfig.get('auth', 'password')
        language = self.testConfig.get('data', 'language')

        # g-l-s does a cache refresh on start.
        ldtp.wait(5)
        self.application.context.click( self.btnInstallRemove )
        ldtp.waittillguiexist( self.frmInstalledLanguages )

        frmInstallCtx = ooldtp.context( self.frmInstalledLanguages )

        ridx = frmInstallCtx.gettablerowindex( self.tblLanguages, language )
        frmInstallCtx.checkrow( self.tblLanguages, ridx, 1 )
        frmInstallCtx.check( self.chkTranslations )
        frmInstallCtx.check( self.chkSpellchecking )
        frmInstallCtx.click( self.btnApplyChanges )
        self.application.authenticate( password )
        # Gives time to the app to install the packages
        ldtp.wait(20)

        # TODO: Check that the packages are installed
        self.assertTrue(True)

    def test_02RemoveLanguage(self):
        """Test the removal of a language package

        Add documentation for your test in the following format:
            caseid: langsel002
            name: administration-language-support-remove
            requires:
            command: gnome-language-selector
            _description:
             PURPOSE:
                 1. Verify the ability to remove an installed language
             STEPS:
                 1. System -> Administration -> Language Support
                 2. Click Install/Remove Language
                 3. Select an installed language
                 7. Proceed with removal
             VERIFICATION:
                 1. Verifiy that the language is not installed

        """
        password = self.testConfig.get('auth', 'password')
        language = self.testConfig.get('data', 'language')

        # g-l-s does a cache refresh on start.
        ldtp.wait(5)
        self.application.context.click( self.btnInstallRemove )
        ldtp.waittillguiexist( self.frmInstalledLanguages )

        frmInstallCtx = ooldtp.context( self.frmInstalledLanguages )

        ridx = frmInstallCtx.gettablerowindex( self.tblLanguages, language )
        frmInstallCtx.uncheckrow( self.tblLanguages, ridx, 1 )
        frmInstallCtx.click( self.btnApplyChanges )
        self.application.authenticate( password )
        # Gives time to the app to remove the packages
        ldtp.wait(20)

        # TODO: Check that the packages are not installed
        self.assertTrue(True)

if __name__ == "__main__":
    unittest.main()
