#!/usr/bin/python
# Copyright (C) 2010 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
""" Generate a basic test for each application listed in 
/usr/share/applications/desktop.en_US.utf8.cache

The basic test launches the application, wait for 3 seconds then closes it
"""
import ConfigParser
from re import sub, search
import os

DESKTOPCACHE = "/usr/share/applications/desktop.en_US.utf8.cache"

#: List of sections to skip. This must be a valid regular expression
# We must exclude window managers to not kill ourselves
BLACKLIST = ['metacity', 'compiz', 'unity' ] 
BINARIES = []

config = ConfigParser.ConfigParser()
config.read( DESKTOPCACHE )

sections = config.sections()

teststr = ""
for section in sorted(config.sections()):
    for v in BLACKLIST:
        if search(v, section): continue

    try:
        binary = config.get( section, 'TryExec' )
    except ConfigParser.NoOptionError:
        binary = config.get( section, 'Exec' )
    except:
        continue

    try:
        name = sub('\W', '', config.get( section, 'Name' ).capitalize())
        terminal = config.get( section, 'Terminal' )
        categories = config.get( section, 'Categories' ).split(';')

        # Skip Terminal applications
        if terminal == 'true': continue
    except ConfigParser.NoOptionError:
        continue

    binary = binary.split(' ')[0]

    if binary in BINARIES: continue
    BINARIES.append(binary)

    teststr += """
class Test%s(TestCase):
    launcher = '%s'

    def test_%s_basic(self):
        ldtp.wait(3)
        self.assertTrue(True)
""" % (name, binary, sub('\W', '', os.path.basename(binary)))

# Generate the testcase script. You need to redirect to a file named
# test_sanitychecks.py to run it with mago
print """# This file was generated by %s
from mago import TestCase
import ldtp
import unittest

%s

if __name__ == "__main__":
    unittest.main()
""" % (os.path.basename(__file__), teststr)
