# Copyright (C) 2010 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

"""Totem Tests

This is a test that verifies that Totem application is working correctly.
So far what it does is:
  - Check General Preferences.
  - Check Display Preferences.
  - Check Sound Preferences.
  - Enable/Disable all plugins.

To run it with:
$ mago-ng <path_to_this_file>
"""

from mago import TestCase
import unittest
import ldtp
import ooldtp


ACCOUNT_ASSISTANT = 'frmMessagingandVoIPAccountsAssistant'
TOTEM = 'frmMoviePlayer'
PREFERENCES = 'dlgPreferences'
MNU_PREFERENCES = 'mnuPreferences'
MNU_PLUGINS = 'mnuPlugins'
GENERAL_TAB = 'ptabGeneral'
DISPLAY_TAB = 'ptabDisplay'
AUDIO_TAB = 'ptabAudio'
BTN_CLOSE = 'btnClose'
TABS = 'ptl0'
PLUGINS = 'dlgConfigurePlugins'
PLUGINS_TABLE = 'tbl0'
#general tab
START_FROM_LAST = 'chkStartplayingfilesfromlastposition'
CONNECTION_SPEED = 'cboConnectionspeed'
LOAD_SUBTITLES = 'chkLoadsubtitlefileswhenmovieisloaded'
LOAD_CHAPTERS = 'chkLoadchapterfileswhenmovieisloaded'
#display tab
RESIZE_WINDOW = 'chkResizethewindowwhenanewvideoisloaded'
DISABLE_DEINTERLACING = 'chkDisabledeinterlacingofinterlacedvideos'
SHOW_EFFECTS = 'chkShowvisualeffectswhenanaudiofileisplayed'
RESET_DEFAULTS = 'btnResettoDefaults'
TYPE_VISUALIZATION = 'cboTypeofvisualization'
VISUALIZATION_SIZE = 'cboVisualizationsize'
#audio tab
AUDIO_OUTPUT = 'cboAudiooutputtype'


class TotemTests(TestCase):
    launcher = 'totem'
    window_name = TOTEM
    setupOnce = True

    def test_01_general_preferences(self):
        """Test that check that the general preferences can be enabled/disabled
        """
        self.enable_disable_general_preferences(True)
        self.enable_disable_general_preferences(False)

    def test_02_display_preferences(self):
        """Test that check that the display preferences can be enabled/disabled
        """
        self.enable_disable_display_preferences(True)
        self.enable_disable_display_preferences(False)

    def test_03_audio_preferences(self):
        """Test that check that the audio preferences can be changed
        """
        self.audio_preferences()

    def test_04_plugins(self):
        """Test that check that the available plugins can be enabled/disabled
        """
        self.enable_disable_plugins(True)
        self.enable_disable_plugins(False)

    def enable_disable_plugins(self, enable):
        totem = ooldtp.context(self.window_name)
        totem.getchild(MNU_PLUGINS).selectmenuitem()
        ldtp.waittillguiexist(PLUGINS)
        plugins = ooldtp.context(PLUGINS)
        row = 0
        while (row < plugins.getchild(PLUGINS_TABLE).getrowcount()):
            if enable:
                plugins.getchild(PLUGINS_TABLE).checkrow(row, 0)
            else:
                plugins.getchild(PLUGINS_TABLE).uncheckrow(row, 0)
            row+=1

        plugins.getchild(BTN_CLOSE).click()

    def enable_disable_general_preferences(self, enable):
        totem = ooldtp.context(self.window_name)
        totem.getchild(MNU_PREFERENCES).selectmenuitem()
        ldtp.waittillguiexist(PREFERENCES)
        pref = ooldtp.context(PREFERENCES)
        pref.selecttab(TABS, GENERAL_TAB)

        if enable:
            pref.getchild(START_FROM_LAST).check()
            pref.getchild(LOAD_SUBTITLES).check()
            pref.getchild(LOAD_CHAPTERS).check()
        else:
            pref.getchild(START_FROM_LAST).uncheck()
            pref.getchild(LOAD_SUBTITLES).uncheck()
            pref.getchild(LOAD_CHAPTERS).uncheck()

        option = 0
        while option < 12:
            pref.getchild(CONNECTION_SPEED).selectindex(option)
            option+=1

        pref.getchild(BTN_CLOSE).click()

    def enable_disable_display_preferences(self, enable):
        totem = ooldtp.context(self.window_name)
        totem.getchild(MNU_PREFERENCES).selectmenuitem()
        ldtp.waittillguiexist(PREFERENCES)
        pref = ooldtp.context(PREFERENCES)
        pref.selecttab(TABS, DISPLAY_TAB)

        if enable:
            pref.getchild(RESIZE_WINDOW).check()
            pref.getchild(DISABLE_DEINTERLACING).check()
            pref.getchild(SHOW_EFFECTS).check()
        else:
            pref.getchild(RESIZE_WINDOW).uncheck()
            pref.getchild(DISABLE_DEINTERLACING).uncheck()
            pref.getchild(SHOW_EFFECTS).uncheck()

        pref.getchild(RESET_DEFAULTS).click()
        pref.getchild(BTN_CLOSE).click()

    def audio_preferences(self):
        totem = ooldtp.context(self.window_name)
        totem.getchild(MNU_PREFERENCES).selectmenuitem()
        ldtp.waittillguiexist(PREFERENCES)
        pref = ooldtp.context(PREFERENCES)
        pref.selecttab(TABS, AUDIO_TAB)

        option = 0
        while option < 6:
            pref.getchild(AUDIO_OUTPUT).selectindex(option)
            option+=1

        pref.getchild(BTN_CLOSE).click()

if __name__ == "__main__":
    unittest.main()
