# -*- coding: utf-8 -*-
# Copyright (C) 2010 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

"""Totem Test

This totem test, test the playboack of totem

To run it with:
    $ mago <path_to_this_file>

"""


from mago import TestCase
import unittest

import ooldtp
import ldtp
import pexpect
import wave
import struct
import numpy as np
import pygst
pygst.require("0.10")
import gst

import os
from time import time, gmtime, strftime


class TestTotem(TestCase):
    """
    totem manages the Totem application.
    """

    launcher = 'totem'
    window_name = 'frmMoviePlayer'

    BTN_ADD = 'btnAdd'
    BTN_CANCEL = 'btnCancel'
    BTN_CLOSE = 'btnClose'
    BTN_DOWN = 'btnDown'
    BTN_FIND = 'btnFind'
    BTN_FULLSCREEN = 'btnFullscreen'
    BTN_NEXTCHAPTER_MOVIE = 'btnNextChapter/Movie'
    BTN_PLAY_PAUSE = 'btnPlay/Pause'
    BTN_PREVIOUSCHAPTER_MOVIE = 'btnPreviousChapter/Movie'
    BTN_REMOVE = 'btnRemove'
    BTN_SAVE = 'btnSave'
    BTN_UP = 'btnUp'

    OPEN_DLG_LOC ='dlgOpenLocation...'
    OPEN_DLG_LOC_TXT = 'txtEntertheaddressofthefileyouwouldliketoopen'
    OPEN_DLG_LOC_OPEN = 'btnOpen'

    MNU_1990331AMPG = 'mnu1990331ampg'
    MNU_ABOUT = 'mnuAbout'
    MNU_ANGLEMENU = 'mnuAngleMenu'
    MNU_AUDIOMENU = 'mnuAudioMenu'
    MNU_CHAPTERMENU = 'mnuChapterMenu'
    MNU_CLEARPLAYLIST = 'mnuClearPlaylist'
    MNU_CONTENTS = 'mnuContents'
    MNU_CREATESCREENSHOTGALLERY = 'mnuCreateScreenshotGallery'
    MNU_DVDMENU = 'mnuDVDMenu'
    MNU_EJECT = 'mnuEject'
    MNU_EMPTY = 'mnuEmpty'
    MNU_EMPTY1 = 'mnuEmpty1'
    MNU_EMPTY2 = 'mnuEmpty2'
    MNU_EMPTY3 = 'mnuEmpty3'
    MNU_EMPTY4 = 'mnuEmpty4'
    MNU_EMPTY5 = 'mnuEmpty5'
    MNU_EMPTY6 = 'mnuEmpty6'
    MNU_EMPTY7 = 'mnuEmpty7'
    MNU_EMPTY8 = 'mnuEmpty8'
    MNU_EMPTY9 = 'mnuEmpty9'
    MNU_FULLSCREEN = 'mnuFullscreen'
    MNU_GETHELPONLINE = 'mnuGetHelpOnline'
    MNU_NEXTCHAPTER_MOVIE = 'mnuNextChapter/Movie'
    MNU_OPEN = 'mnuOpen'
    MNU_OPENLOCATION = 'mnuOpenLocation'
    MNU_PLAY_PAUSE = 'mnuPlay/Pause'
    MNU_PLUGINS = 'mnuPlugins'
    MNU_PREFERENCES = 'mnuPreferences'
    MNU_PREVIOUSCHAPTER_MOVIE = 'mnuPreviousChapter/Movie'
    MNU_PROPERTIES = 'mnuProperties'
    MNU_QUIT = 'mnuQuit'
    MNU_REPORTAPROBLEM = 'mnuReportaProblem'
    MNU_RESIZE11 = 'mnuResize11'
    MNU_RESIZE12 = 'mnuResize12'
    MNU_RESIZE21 = 'mnuResize21'
    MNU_SELECTTEXTSUBTITLES = 'mnuSelectTextSubtitles'
    MNU_SKIPBACKWARDS = 'mnuSkipBackwards'
    MNU_SKIPFORWARD = 'mnuSkipForward'
    MNU_SKIPTO = 'mnuSkipto'
    MNU_SWITCHANGLES = 'mnuSwitchAngles'
    MNU_TAKESCREENSHOT = 'mnuTakeScreenshot'
    MNU_TITLEMENU = 'mnuTitleMenu'
    MNU_TRANSLATETHISAPPLICATION = 'mnuTranslateThisApplication'
    MNU_VOLUMEDOWN = 'mnuVolumeDown'
    MNU_VOLUMEUP = 'mnuVolumeUp'
    MNU_ZOOMIN = 'mnuZoomIn'
    MNU_ZOOMOUT = 'mnuZoomOut'
    MNU_ZOOMRESET = 'mnuZoomReset'
    MNU_PLAYLIST = 'mnuplaylist'
    MNU_PROPERTIES = 'mnuproperties'
    MNU_YOUTUBE = 'mnuyoutube'
    TXT_0 = 'txt0'

    wavfile = '/tmp/totem.wav'
    freq=440


    def setUp(self):
        super(TestTotem, self).setUp()
        pipeline = 'audiotestsrc freq=%d num-buffers=1024 ! queue ! \
            audioconvert ! \
            audio/x-raw-int,width=16,depth=16,channels=1 ! \
            wavenc ! \
            filesink location=%s' % (self.freq, self.wavfile)
        element = gst.parse_launch(pipeline)
        element.set_state(gst.STATE_PLAYING)


    def test_totem_audio_playback(self):
        test_file = strftime(
            "/tmp/" + "%Y%m%d_%H%M%S" + ".wav", gmtime((time())))
        self.openfile(self.wavfile)
        (freq, flat) = self.capture_do_fft(test_file)
        if freq != self.freq:
            raise AssertionError, "Sine WAV playback error, frq expected: %s ; got %s" % (self.freq, freq)
        self.play_pause()
        os.unlink(test_file)
        (freq, flat) = self.capture_do_fft(test_file)
        if flat != 1:
            raise AssertionError, "Pause playback error, non flat PCM detected"
        self.play_pause()
        os.unlink(test_file)

    def openfile(self, filename, open_menu='mnuOpenLocation'):
        """
        It tries to open/play the filename passed as parameter.

        @type filename: string
        @param filename: The name of the file to open.
        """
        totem = ooldtp.context(self.window_name)
        actualMenu = totem.getchild(open_menu)
        actualMenu.selectmenuitem()
        ldtp.waittillguiexist(self.OPEN_DLG_LOC)
        ldtp.wait(1)
        open_dialog_loc = ooldtp.context(self.OPEN_DLG_LOC)
        open_dlg_loc_txt_filename = open_dialog_loc.getchild(self.OPEN_DLG_LOC_TXT)
        ldtp.wait(1)
        open_dlg_loc_txt_filename.settextvalue("file://%s" %filename)
        open_dlg_loc_btn_open = open_dialog_loc.getchild(self.OPEN_DLG_LOC_OPEN)
        ldtp.wait(1)
        open_dlg_loc_btn_open.click()
        ldtp.waittillguinotexist(self.OPEN_DLG_LOC)
        ldtp.wait(1)
        #self.set_name(os.path.basename(filename))

    def capture_do_fft(self, filename):
        """
        Start a Gstreamer pipeline to record ALSA PCM output
        Perform FFT to find freq peak

        Return:
            - the freq peak
            - a boolean if the PCM recorded is flat (no sound)
        """

        device = pexpect.run('/bin/bash -c "pactl list | \
            grep -A2 \'^Source #\' | \
            grep -e \'Name: .*\.monitor$\' | cut -d\' \' -f2 | tail -n1"')

        pipeline = 'pulsesrc device=%s ! queue ! audioconvert ! \
            audio/x-raw-int,width=16,depth=16,channels=1 ! \
            wavenc ! filesink location=%s' % (device.rstrip(), filename)
        element = gst.parse_launch(pipeline)
        element.set_state(gst.STATE_PLAYING)
        ldtp.wait(2)
        element.set_state(gst.STATE_NULL)

        data_size = 40000
        frate = 44100.0
        wav_file = wave.open(filename,'r')
        data = wav_file.readframes(data_size)
        wav_file.close()
        data = struct.unpack('<{n}h'.format(n=data_size), data)
        data = np.array(data)
        w = np.fft.fft(data)
        freqs = np.fft.fftfreq(len(w))

        # A flat PCM is made of the following values : -1, 0, 1 only
        flat = 0 if (abs(np.min(data))+abs(np.max(data))-2) else 1

        # Find the peak in the coefficients
        idx = np.argmax(np.abs(w)**2)
        freq = freqs[idx]
        freq_in_hertz = abs(freq*frate)
        return ((int(round(freq_in_hertz))), flat)

    def play_pause(self):
        totem = ooldtp.context(self.name)
        btn_play_pause = totem.getchild(self.BTN_PLAY_PAUSE)
        #ldtp.wait(1)
        btn_play_pause.click()
        ldtp.wait(2)

