# Copyright (C) 2010 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

"""Transmission GTK Test

This is a test that verifies that Transmission application is working correctly.
So far what it does is:
  - Add a torrent URL.
  - Check that the torrent is being downloaded.
  - Remove the torrent and the files downloaded.

This test only requires an Internet connection to be run.

To run it with: 
$ mago-ng <path_to_this_file>
"""

from mago import TestCase
import unittest
import ldtp
import ooldtp

TRANSMISSION = 'frmTransmission'
DLG_INFORMATION = 'dlgInformation'
IACCEPT = 'btnIAccept'
MNU_ADD_URL = 'mnuAddURL'
DLG_ADD_URL = 'dlgAddURL'
TXT_ADD_URL = 'txtURL'
BTN_ADD_URL = 'btnAdd'
DLG_TORRENT_OPTIONS = 'dlgTorrentOptions'
DLG_QUESTION = 'dlgQuestion'
BTN_REMOVE = 'btnDelete'
TABLE = 'tbl0'
MNU_REMOVE_TORRENT = 'mnuDeleteFilesandRemove'
SPEED = 'lbl*KiB/s'
"""This is the torrent image we download 
"""
TORRENT = 'http://cdimage.ubuntu.com/releases/maverick/release/ubuntu-10.10-dvd-i386.iso.torrent'

class TransmissionsTests(TestCase):    
    """Launcher for the application transmission
    """
    launcher = 'transmission-gtk'
    window_name =  TRANSMISSION
    setupOnce = True
    
    def transmission_01_test_add_torrent(self):
        """Test that adding a torrent works fine.
        When you launch transmission for the first time and information dialog
        is being displayed with information regarding torrents, we wait for
        that dialog and accept.
        """
        if ldtp.guiexist(DLG_INFORMATION):
            i = ooldtp.context(DLG_INFORMATION)
            i.getchild(IACCEPT).click()
            
        t = ooldtp.context(TRANSMISSION)
        t.getchild(MNU_ADD_URL).selectmenuitem()
        
        ldtp.waittillguiexist(DLG_ADD_URL)
        du = ooldtp.context(DLG_ADD_URL)
        du.getchild(TXT_ADD_URL).settextvalue(TORRENT)
        du.getchild(BTN_ADD_URL).click()
         
        ldtp.waittillguiexist(DLG_TORRENT_OPTIONS)
        
        if ldtp.guiexist(DLG_TORRENT_OPTIONS):
            to = ooldtp.context(DLG_TORRENT_OPTIONS)
            to.getchild(BTN_ADD_URL).click()

        self.assertTrue(ldtp.guiexist(TRANSMISSION))

    def transmission_02_test_check_torrent(self):
        """Test that checks that the torrent is being downloaded, we double check
        that the treeview contains the torrent element and that the speed changes.
        """
        t = ooldtp.context(TRANSMISSION)
        table = t.getchild(TABLE)
        self.assertTrue(table.getrowcount() > 0)
        """wait until the torrent has started to download.
        """
        while t.getchild(SPEED).gettextvalue() == '0.00 KiB/s':
            ldtp.wait(2)
    
    def transmission_03_test_remove_torrent(self):
        """Test that removes the torrent and the files.
        """
        t = ooldtp.context(TRANSMISSION)
        table = t.getchild(TABLE)
        table.selectrowindex(0)
        t.getchild(MNU_REMOVE_TORRENT).selectmenuitem()
        
        ldtp.waittillguiexist(DLG_QUESTION)

        if ldtp.guiexist(DLG_QUESTION):
            q = ooldtp.context(DLG_QUESTION)
            q.getchild(BTN_REMOVE).click()
        
        self.assertTrue(table.getrowcount() == 0)
        
if __name__ == "__main__":
    unittest.main()
